@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 """
-mpdscrobble
+A simple Last.fm scrobbler for MPD.
 """
 
-__version__ = "0.2.7"
+__version__ = "0.3.1"
 
 name = "mpdscrobble"
